@@ -1,4 +1,3 @@
-#!/usr/bin/env perl
 #-*- Mode: perl; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 
 # replace.pl: Common in-line replacing stuff for the ximian-setup-tools backends.
@@ -77,7 +76,7 @@ sub run_entry
   }
   
   # OK, the given entry didn't have any array refs in it...
-  
+
   return -1 if (!&Utils::Parse::replace_hash_values ($ncp, $values_hash));
   push (@$ncp, $$values_hash{$key}) unless $key eq "_always_";
   $res = -1 if &$proc (@$ncp);
@@ -102,7 +101,7 @@ sub set_from_table
   my ($i, @cp, @files, $res);
 
   $$fn{"OLD_HASH"} = $old_hash;
-  
+
   foreach $i (@$table)
   {
     @cp = @$i;
@@ -118,7 +117,7 @@ sub set_from_table
     }
     elsif ((!exists $$values_hash{$key}) && (exists $$old_hash{$key}))
     {
-      # we need to remove all the instances of the known variables that doesn't exist in the XML
+      # we need to remove all the instances of the known variables that doesn't exist in the data structure
       $res = &run_entry ($values_hash, $key, $proc, \@cp, undef);
     }
   }
@@ -539,6 +538,7 @@ sub set_ini
   my ($file, $section, $var, $value) = @_;
   my ($buff, $i, $found_flag, $ret);
   my ($pre_space, $post_comment, $sec_save);
+  my ($escaped_section);
 
   &Utils::Report::enter ();
   &Utils::Report::do_report ("replace_ini", $var, $section, $file);
@@ -547,6 +547,7 @@ sub set_ini
 
   &Utils::File::join_buffer_lines ($buff);
   $found_flag = 0;
+  $escaped_section = Utils::Parse::escape ($section);
   
   foreach $i (@$buff)
   {
@@ -558,9 +559,9 @@ sub set_ini
     
     if ($i ne "")
     {
-      if ($i =~ /\[$section\]/i)
+      if ($i =~ /\[$escaped_section\]/i)
       {
-        $i =~ s/(\[$section\][ \t]*)//i;
+        $i =~ s/(\[$escaped_section\][ \t]*)//i;
         $sec_save = $1;
         $found_flag = 1;
       }
@@ -572,7 +573,7 @@ sub set_ini
           $i = "$var = $value\n$i" if ($value ne "");
           $found_flag = 2;
         }
-        
+
         if ($i =~ /^$var[ \t]*=/i)
         {
           if ($value ne "")
@@ -613,11 +614,13 @@ sub remove_ini_section
   my ($file, $section) = @_;
   my ($buff, $i, $found_flag, $ret);
   my ($pre_space, $post_comment, $sec_save);
+  my ($escaped_section);
 
   &Utils::Report::enter ();
   &Utils::Report::do_report ("replace_del_ini_sect", $section, $file);
 
   $buff = &Utils::File::load_buffer ($file);
+  $escaped_section = &Utils::Parse::escape ($section);
 
   &Utils::File::join_buffer_lines ($buff);
   $found_flag = 0;
@@ -632,9 +635,9 @@ sub remove_ini_section
     
     if ($i ne "")
     {
-      if ($i =~ /\[$section\]/i)
+      if ($i =~ /\[$escaped_section\]/i)
       {
-        $i =~ s/(\[$section\][ \t]*)//i;
+        $i =~ s/(\[$escaped_section\][ \t]*)//i;
         $found_flag = 1;
       }
       elsif ($found_flag && $i =~ /\[.+\]/i)
